@@ -109,11 +109,12 @@ class ModelSpecLoader(SimpleInterface):
             if not isdefined(models):
                 # model is not yet standardized, so validate=False
                 # Ignore all subject directories and .git/ and .datalad/ directories
+                indexer = bids.BIDSLayoutIndexer(
+                    ignore=[re.compile(r'sub-'), re.compile(r'\.(git|datalad)')])
                 small_layout = bids.BIDSLayout(
                     layout.root, derivatives=[d.root for d in layout.derivatives.values()],
                     validate=False,
-                    ignore=[re.compile(r'sub-'),
-                            re.compile(r'\.(git|datalad)')])
+                    indexer=indexer)
                 # PyBIDS can double up, so find unique models
                 models = list(set(small_layout.get(suffix='smdl', return_type='file')))
                 if not models:
@@ -126,7 +127,7 @@ class ModelSpecLoader(SimpleInterface):
         if self.inputs.selectors:
             # This is almost certainly incorrect
             models = [model for model in models
-                      if all(val in model['input'].get(key, [val])
+                      if all(val in model['Input'].get(key, [val])
                              for key, val in self.inputs.selectors.items())]
 
         self._results['model_spec'] = models
@@ -235,7 +236,7 @@ class LoadBIDSModel(SimpleInterface):
         for coll in step.get_collections():
             sparse = dense = None
             try:
-                sparse = coll.to_df(include_dense=False)
+                sparse = coll.to_df(include_dense=False, format='long')
             except ValueError:
                 pass
             try:
